@@ -24,6 +24,7 @@
 """Enzyme optimization."""
 
 import json
+import logging
 import random
 import time
 from collections import OrderedDict
@@ -31,7 +32,6 @@ from typing import Any, Dict, List, MutableMapping, Optional, Sequence, Tuple, U
 
 import numpy as np
 from joblib import load
-from loguru import logger
 
 from .processing import (
     HuggingFaceTransformerEmbedding,
@@ -41,6 +41,9 @@ from .processing import (
     sanitize_intervals,
 )
 
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
+
 #: transition matrix representation
 TransitionMatrix = MutableMapping[str, MutableMapping[str, float]]
 #: transition matrix configuration
